/*
 * $HEADER$
 */
#if defined(c_plusplus) || defined(__cplusplus)
extern "C" {
#endif



const pmix_mca_base_component_t *pmix_mca_pnet_base_static_components[] = {

  NULL
};

#if defined(c_plusplus) || defined(__cplusplus)
}
#endif

